v2.1.0
------

Changes
~~~~~~~
- Adding build, coverage, and quality badges to README.rst. [Ash Wilson]
- Python 3.6, 3.7 compatibility. [Ash Wilson]

Other
~~~~~
- Create pyup.io config file. [pyup-bot]


v2.0 (2018-10-17)
-----------------

Changes
~~~~~~~
- Better-structured format for channel scans. [Ash Wilson]
- Adding CodeClimate config. [Ash Wilson]

  Removing Python2.6 because this ain't the antique roadshow.

  Closes #3
- Add "avg_absolute_error" to scan_channel() output. [Ash Wilson]


v1.1.1 (2017-01-06)
-------------------
- Update travis. [ashmastaflash]


